use std::time::Duration;

use tokio::time;
use tracing::debug;

use crate::json::alerts::Alerts;

mod json {
    pub mod alert;
    pub mod alerts;
    pub mod area;
    pub mod circle;
    pub mod contact;
    pub mod coordinate;
    pub mod description;
    pub mod image;
    pub mod image_description;
    pub mod image_title;
    pub mod link;
    pub mod polygon;
    pub mod region;
    pub mod text;
    pub mod title;
}
mod logging;

#[tokio::main]
async fn main() {
    logging::setup("alert-me");

    let mut interval = time::interval(Duration::from_secs(5));

    loop {
        interval.tick().await;
        let resp = reqwest::get("https://www.alert.swiss/content/alertswiss-internet/en/home/_jcr_content/polyalert.alertswiss_alerts.actual.json")
            .await
            .unwrap()
            .json::<Alerts>()
            .await.unwrap();
        debug!("{resp:#?}");
    }
}
